@@ -1,5 +1,5 @@
 package Mira::Control::Content::Address;
-$Mira::Control::Content::Address::VERSION = '00.07.22';
+$Mira::Control::Content::Address::VERSION = '00.07.23';
 
 use strict;
 use warnings;
@@ -106,7 +106,9 @@ sub address {
       #$permalink =~ s"(?<!http:)/+"/"g;
 
       @permalink = split (/\//, $permalink);
-      $self->{$utid}->{_spec}->{address} = catfile(@permalink, "index.html");
+      my $ext = $config->{$floor}->{output_extension} || 'html';
+      $ext =~ s{^\.+}{};
+      $self->{$utid}->{_spec}->{address} = catfile(@permalink, "index.$ext");
       $self->{$utid}->{url} = $permalink;
       $self->{$utid}->{url} =~ s{(?<!:)/+}{/}g;
       #$self->{$utid}->{url} =~ s"(?<!http:)/+"/"g;
