@@ -1,5 +1,5 @@
 package Mira::Control::Parser::img;
-$Mira::Control::Parser::img::VERSION = '00.07.22';
+$Mira::Control::Parser::img::VERSION = '00.07.23';
 
 use strict;
 use warnings;
@@ -12,11 +12,13 @@ sub replace {
   my $self = shift;
   my $static_img_addr = shift;
 
-  while ($self =~ /(?<!\\)\{\{\s+img\s+([^\s]*?)\s*(".*?")?\s*(".*?")?\s*\}\}/g)
+  while ($self =~ /(?<!\\)\{\{\s+img\s+([^\s]*?)\s*(\[.*?\])?\s*(\[.*?\])?\s*\}\}/g)
   {
     my $source = $1 if $1;
     my $alt = $2 if $2;
     my $title = $3 ? $3 : ($2 ? $2 : '');
+    $alt   =~ s/^\[|\]$/"/g if $alt;
+    $title =~ s/^\[|\]$/"/g if $title;
     next unless $source;
 
     my $imgurl = $static_img_addr;
@@ -27,7 +29,7 @@ sub replace {
     $addr .= " title=$title" if $title;
     $addr .= " >";
     $addr =~ s"(?<!:)/+"/"g;
-    $self =~ s/(?<!\\)\{\{\s+img\s+([^\s]*?)\s*(".*?")?\s*(".*?")?\s*\}\}/$addr/;
+    $self =~ s/(?<!\\)\{\{\s+img\s+([^\s]*?)\s*(\[.*?\])?\s*(\[.*?\])?\s*\}\}/$addr/;
   }
 
     $self =~ s/\\\{\{\s+img\s+/\{\{\ img\ /g;
