@@ -1,5 +1,5 @@
 package Mira::Control::Plugin::Load;
-$Mira::Control::Plugin::Load::VERSION = '00.07.22';
+$Mira::Control::Plugin::Load::VERSION = '00.07.23';
 
 use strict;
 use warnings;
@@ -19,17 +19,17 @@ sub check {
   my $config = shift;
   my @check;
 
-  if ($config->{plugin}){ foreach my $plugin (@{$config->{plugin}})
+  if ($config->{plugins}){ foreach my $plugin (@{$config->{plugins}})
   {
     if (my $chkinst = check_install( module => "Mira::Plugin::$plugin"))
     {
-      say "PLUGINS >>> package Mira::Plugin::$plugin is " . ($chkinst ? '' : 'NOT ') . "Loaded";
+      say "PLUGINS >>> package Mira::Plugin::$plugin is Loaded";
       push @check, "Mira::Plugin::$plugin";
       next;
     }
     if (my $chkinst = check_install( module => $plugin))
     {
-      say "PLUGINS >>> $plugin is " . ($chkinst ? '' : 'NOT ') . "Loaded";
+      say "PLUGINS >>> $plugin is Loaded";
       push @check, $plugin;
       next;
     }
