@@ -1,5 +1,5 @@
 package Mira::View::Floor;
-$Mira::View::Floor::VERSION = '00.07.22';
+$Mira::View::Floor::VERSION = '00.07.23';
 
 use strict;
 use warnings;
@@ -28,10 +28,21 @@ sub template {
 
   foreach my $floor (keys %$floors)
   {
-    my $floor_template_root =
-      (-f catfile($pensource,'template',$config->{$floor}->{template},'index.tt2') )
-      ? catdir($pensource,'template',$config->{$floor}->{template})
-      : catdir($pensource,'template', $config->{_default}->{template});
+    my $floor_template_root;
+      if
+      (-f catfile($pensource,'template',$config->{$floor}->{template},'index.tt2'))
+      {
+        $floor_template_root =
+           catdir($pensource,'template',$config->{$floor}->{template})
+      } elsif
+      (-f catfile($pensource,'template',$config->{_default}->{template},'index.tt2'))
+      {
+        $floor_template_root =
+           catdir($pensource,'template', $config->{_default}->{template})
+      } else
+      {
+        next;
+      }
 
 
     my @utids = @{$floors->{$floor}};
@@ -150,17 +161,19 @@ sub template {
           }
           $vars->{POSTS} = $posts;
 
-          my $target = $page_number == 1 ? "index.html" : "/page/$page_number/index.html";
+          my $ext = $config->{$floor}->{output_extension} || 'html';
+          $ext =~ s{^\.+}{};
+          my $target = $page_number == 1 ? "index.$ext" : "/page/$page_number/index.$ext";
           my $index = catfile($pensource, 'public', $config->{$floor}->{root}, $target);
 
           $page->{next}->{url} = @utids ? "$config->{$floor}->{root}/page/" . ($page_number+1) . "/" : '' ;
-          $page->{next}->{url} =~ s{(?<!http:)\/+}{\/}g if $page->{next}->{url};
+          $page->{next}->{url} =~ s{^(.*?):/+}{/} if $page->{next}->{url};
           $page->{next}->{title} = ($page_number+1) if $vars->{next}->{url};
           delete $page->{next} unless $page->{next}->{url};
 
           $page->{prev}->{url} = $page_number == 1 ? '' : "$config->{$floor}->{root}/page/" . ($page_number-1) . "/" ;
           $page->{prev}->{url} = $config->{$floor}->{root} . "/" if $page_number == 2;
-          $page->{prev}->{url} =~ s{(?<!http:)/+}{/}g if $page->{prev}->{url};
+          $page->{prev}->{url} =~ s{^(.*?):/+}{/} if $page->{prev}->{url};
           $page->{prev}->{title} = ($page_number-1) if $vars->{prev}->{url};
           delete $page->{prev} unless $page->{prev}->{url};
 
