@@ -1,5 +1,5 @@
 package Mira::View::Main;
-$Mira::View::Main::VERSION = '00.07.22';
+$Mira::View::Main::VERSION = '00.07.23';
 
 use strict;
 use warnings;
@@ -22,7 +22,15 @@ sub template {
   my $floor_data = $switches{floor_data};
   my $build = $switches{build};
 
-  my $template_root = catdir($pensource,'template', $config->{_default}->{template});
+  my $template_root;
+
+  if ( -f catfile($pensource,'template', $config->{_default}->{template}, 'main.tt2') )
+  {
+    $template_root = catdir($pensource,'template', $config->{_default}->{template});
+  } else
+  {
+    return;
+  }
 
   my $root_index = Template->new({
       INCLUDE_PATH => [$template_root, catdir($template_root, 'include') ],
@@ -60,13 +68,14 @@ sub template {
    $vars->{MainURL} =~ s{(?<!:)/+}{/}g;
    $vars->{MainURL} =~ s{/$}{}g;
 
-   $vars->{MainROOT} =~ s{^(.*?):/+}{/}g;
+   $vars->{MainROOT} =~ s{^(.*?):/+}{/};
    $vars->{MainROOT} = "/" . $vars->{MainROOT} if $vars->{MainROOT} !~ m:^/:;
    $vars->{MainROOT} =~ s{/+}{/}g;
    $vars->{MainROOT} =~ s{/$}{}g unless $vars->{MainROOT} eq "/";
 
-
-  my $index = catfile($pensource, 'public', $config->{_default}->{root}, 'index.html');
+  my $ext = $config->{_default}->{output_extension} || 'html';
+  $ext =~ s{^\.+}{};
+  my $index = catfile($pensource, 'public', $config->{_default}->{root}, "index.$ext");
   $root_index->process('main.tt2', $vars, $index, { binmode => ':utf8' })
       || die $root_index->error(), "\n";
 
